==> gcc-4.1.2.tar.bz2: gcc-4.1.2/libjava/classpath/java/security/spec/PSSParameterSpec.java <==
/* PSSParameterSpec.java --
   Copyright (C) 2003, Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.security.spec;

/**
 * This class specifies a parameter spec for RSA PSS encoding scheme, as
 * defined in the PKCS#1 v2.1.
 *
 * @since 1.4
 * @see AlgorithmParameterSpec
 * @see java.security.Signature
 */
public class PSSParameterSpec implements AlgorithmParameterSpec
{
  // Constants and fields
  // --------------------------------------------------------------------------

  private int saltLen;

  // Constructor(s)
  // --------------------------------------------------------------------------

  /**
   * Creates a new <code>PSSParameterSpec</code> given the salt length as
   * defined in PKCS#1.
   *
   * @param saltLen the length of salt in bits to be used in PKCS#1 PSS encoding.
   * @throws IllegalArgumentException if <code>saltLen</code> is less than
   * <code>0</code>.
   */
  public PSSParameterSpec(int saltLen)
  {
    super();

    if (saltLen < 0)
      throw new IllegalArgumentException();
    this.saltLen = saltLen;
  }

  // Class methods
  // --------------------------------------------------------------------------

  // Instance methods
  // --------------------------------------------------------------------------

  /**
   * Returns the salt length in bits.
   *
   * @return the salt length.
   */
  public int getSaltLength()
  {
    return this.saltLen;
  }
}

==> gcc-4.5.3.tar.bz2: gcc-4.5.3/libjava/classpath/java/security/spec/PSSParameterSpec.java <==
/* PSSParameterSpec.java --
   Copyright (C) 2003, Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.security.spec;

/**
 * An implementation of {@link AlgorithmParameterSpec} for the RSA PSS encoding
 * scheme.
 * 
 * @since 1.4
 * @see AlgorithmParameterSpec
 * @see java.security.Signature
 */
public class PSSParameterSpec implements AlgorithmParameterSpec
{
  // Constants and fields
  // --------------------------------------------------------------------------

  private int saltLen;

  // Constructor(s)
  // --------------------------------------------------------------------------

  /**
   * Construct a new instance of <code>PSSParameterSpec</code> given a salt
   * length.
   * 
   * @param saltLen
   *          the length in bits of the salt.
   * @throws IllegalArgumentException
   *           if <code>saltLen</code> is less than <code>0</code>.
   */
  public PSSParameterSpec(int saltLen)
  {
    super();

    if (saltLen < 0)
      throw new IllegalArgumentException();
    this.saltLen = saltLen;
  }

  // Class methods
  // --------------------------------------------------------------------------

  // Instance methods
  // --------------------------------------------------------------------------

  /** @return the length (in bits) of the salt. */
  public int getSaltLength()
  {
    return this.saltLen;
  }
}
